@@ -3,7 +3,7 @@ package Specio::Constraint::AnyCan;
 use strict;
 use warnings;
 
-our $VERSION = '0.14';
+our $VERSION = '0.15';
 
 use B ();
 use List::Util 1.33 ();
@@ -45,7 +45,7 @@ EOF
     sub _build_inline_generator {$_inline_generator}
 }
 
-__PACKAGE__->_ooify();
+__PACKAGE__->_ooify;
 
 1;
 
@@ -63,12 +63,12 @@ Specio::Constraint::AnyCan - A class for constraints which require a class name
 
 =head1 VERSION
 
-version 0.14
+version 0.15
 
 =head1 SYNOPSIS
 
     my $type = Specio::Constraint::AnyCan->new(...);
-    print $_, "\n" for @{ $type->methods() };
+    print $_, "\n" for @{ $type->methods };
 
 =head1 DESCRIPTION
 
@@ -95,7 +95,7 @@ an array reference of method names which the constraint requires. You can also
 pass a single string and it will be converted to an array reference
 internally.
 
-=head2 $any_can->methods()
+=head2 $any_can->methods
 
 Returns an array reference containing the methods this constraint requires.
 
