@@ -3,7 +3,7 @@ package Specio::Constraint::AnyDoes;
 use strict;
 use warnings;
 
-our $VERSION = '0.14';
+our $VERSION = '0.15';
 
 use B ();
 use Role::Tiny::With;
@@ -44,7 +44,7 @@ EOF
     sub _build_inline_generator {$_inline_generator}
 }
 
-__PACKAGE__->_ooify();
+__PACKAGE__->_ooify;
 
 1;
 
@@ -62,12 +62,12 @@ Specio::Constraint::AnyDoes - A class for constraints which require a class name
 
 =head1 VERSION
 
-version 0.14
+version 0.15
 
 =head1 SYNOPSIS
 
     my $type = Specio::Constraint::AnyDoes->new(...);
-    print $type->role();
+    print $type->role;
 
 =head1 DESCRIPTION
 
@@ -92,7 +92,7 @@ This class overrides the C<message_generator> default if none is provided.
 Finally, this class requires an additional parameter, C<role>. This must be a
 single role name.
 
-=head2 $any_isa->role()
+=head2 $any_isa->role
 
 Returns the role name passed to the constructor.
 
