@@ -3,7 +3,7 @@ package Specio::Constraint::AnyIsa;
 use strict;
 use warnings;
 
-our $VERSION = '0.14';
+our $VERSION = '0.15';
 
 use B ();
 use Role::Tiny::With;
@@ -42,7 +42,7 @@ EOF
     sub _build_inline_generator {$_inline_generator}
 }
 
-__PACKAGE__->_ooify();
+__PACKAGE__->_ooify;
 
 1;
 
@@ -60,12 +60,12 @@ Specio::Constraint::AnyIsa - A class for constraints which require a class name
 
 =head1 VERSION
 
-version 0.14
+version 0.15
 
 =head1 SYNOPSIS
 
     my $type = Specio::Constraint::AnyIsa->new(...);
-    print $type->class();
+    print $type->class;
 
 =head1 DESCRIPTION
 
@@ -90,7 +90,7 @@ This class overrides the C<message_generator> default if none is provided.
 Finally, this class requires an additional parameter, C<class>. This must be a
 single class name.
 
-=head2 $any_isa->class()
+=head2 $any_isa->class
 
 Returns the class name passed to the constructor.
 
