@@ -3,7 +3,7 @@ package Specio::Constraint::Role::DoesType;
 use strict;
 use warnings;
 
-our $VERSION = '0.14';
+our $VERSION = '0.15';
 
 use Role::Tiny;
 use Storable qw( dclone );
@@ -38,7 +38,7 @@ sub _wrap_message_generator {
     my $self      = shift;
     my $generator = shift;
 
-    my $role = $self->role();
+    my $role = $self->role;
 
     $generator //= sub {
         my $description = shift;
@@ -46,12 +46,12 @@ sub _wrap_message_generator {
 
         return
               "Validation failed for $description with value "
-            . Devel::PartialDump->new()->dump($value)
+            . Devel::PartialDump->new->dump($value)
             . '(does not do '
             . $role . ')';
     };
 
-    my $d = $self->_description();
+    my $d = $self->_description;
 
     return sub { $generator->( $d, @_ ) };
 }
@@ -73,7 +73,7 @@ Specio::Constraint::Role::DoesType - Provides a common implementation for Specio
 
 =head1 VERSION
 
-version 0.14
+version 0.15
 
 =head1 DESCRIPTION
 
