@@ -3,14 +3,14 @@ package Specio::Constraint::Simple;
 use strict;
 use warnings;
 
-our $VERSION = '0.14';
+our $VERSION = '0.15';
 
 use Role::Tiny::With;
 use Specio::OO;
 
 with 'Specio::Constraint::Role::Interface';
 
-__PACKAGE__->_ooify();
+__PACKAGE__->_ooify;
 
 1;
 
@@ -28,15 +28,15 @@ Specio::Constraint::Simple - Class for simple (non-parameterized or specialized)
 
 =head1 VERSION
 
-version 0.14
+version 0.15
 
 =head1 SYNOPSIS
 
     my $str = t('Str');
 
-    print $str->name(); # Str
+    print $str->name; # Str
 
-    my $parent = $str->parent();
+    my $parent = $str->parent;
 
     if ( $str->value_is_valid($value) ) { ... }
 
@@ -108,7 +108,7 @@ subroutine something like this:
       my $self = shift;
       my $var  = shift;
 
-      return $_[0]->parent()->inline_check( $_[1] )
+      return $_[0]->parent->inline_check( $_[1] )
           . ' and more checking code goes here';
   }
 
@@ -167,11 +167,11 @@ This parameter is required.
 
 It is possible to create a type without a constraint of its own.
 
-=head2 $type->name(), $type->parent()
+=head2 $type->name, $type->parent
 
 Returns the value of these parameters as they were passed to the constructor.
 
-=head2 $type->is_anon()
+=head2 $type->is_anon
 
 Returns false for named types, true otherwise.
 
@@ -185,7 +185,7 @@ a descendant of that type or is that type.
 Given a type object, this returns true if the type this method is called on is
 the same as that type.
 
-=head2 $type->coercions()
+=head2 $type->coercions
 
 Returns a list of L<Specio::Coercion> objects which belong to this constraint.
 
@@ -204,13 +204,13 @@ L<Specio::Exception>.
 Returns true or false depending on whether the C<$value> passes the type
 constraint.
 
-=head2 $type->has_real_constraint()
+=head2 $type->has_real_constraint
 
 This returns true if the type was created with a C<constraint> or
 C<inline_generator> parameter. This is used internally to skip type checks for
 types that don't actually implement a constraint.
 
-=head2 $type->id()
+=head2 $type->id
 
 This is a unique id for the type as a string. This is useful if you need to
 make a hash key based on a type, for example.
@@ -267,7 +267,7 @@ C<eval_closure> subroutine.
 Given a variable name, this returns a string of code that implements the
 constraint. If the type is not inlinable, this method throws an error.
 
-=head2 $type->coercion_sub()
+=head2 $type->coercion_sub
 
 This method returns a sub ref that takes a single argument and applied all
 relevant coercions to it. This sub ref will use L<Sub::Quote> if all the
