@@ -3,7 +3,7 @@ package Specio::DeclaredAt;
 use strict;
 use warnings;
 
-our $VERSION = '0.14';
+our $VERSION = '0.15';
 
 use Specio::OO;
 
@@ -49,19 +49,19 @@ sub new_from_caller {
 sub description {
     my $self = shift;
 
-    my $package  = $self->package();
-    my $filename = $self->filename();
-    my $line     = $self->line();
+    my $package  = $self->package;
+    my $filename = $self->filename;
+    my $line     = $self->line;
 
     my $desc = "declared in package $package ($filename) at line $line";
-    if ( $self->has_subroutine() ) {
-        $desc .= ' in sub named ' . $self->subroutine();
+    if ( $self->has_subroutine ) {
+        $desc .= ' in sub named ' . $self->subroutine;
     }
 
     return $desc;
 }
 
-__PACKAGE__->_ooify();
+__PACKAGE__->_ooify;
 
 1;
 
@@ -79,18 +79,18 @@ Specio::DeclaredAt - A class to represent where a type or coercion was declared
 
 =head1 VERSION
 
-version 0.14
+version 0.15
 
 =head1 SYNOPSIS
 
     my $declared = Specio::DeclaredAt->new_from_caller(1);
 
-    print $declared->description();
+    print $declared->description;
 
 =head1 DESCRIPTION
 
 This class provides a thin wrapper around some of the return values from
-Perl's C<caller()> built-in. It's used internally to identify where types and
+Perl's C<caller> built-in. It's used internally to identify where types and
 coercions are being declared, which is useful when generating error messages.
 
 =head1 API
@@ -102,20 +102,20 @@ This class provides the following methods.
 Given a call stack depth, this method returns a new C<Specio::DeclaredAt>
 object.
 
-=head2 $declared_at->package(), $declared_at->filename(), $declared_at->line()
+=head2 $declared_at->package, $declared_at->filename, $declared_at->line
 
 Returns the call stack information recorded when the object was created. These
 values are always populated.
 
-=head2 $declared_at->subroutine()
+=head2 $declared_at->subroutine
 
 Returns the subroutine from the call stack. This may be an C<udnef>
 
-=head2 $declared_at->has_subroutine()
+=head2 $declared_at->has_subroutine
 
 Returns true if there is a subroutine name associated with this object.
 
-=head2 $declared_at->description()
+=head2 $declared_at->description
 
 Puts all the information together into a single string like "declared in
 package Foo::Bar (.../Foo/Bar.pm) at line 42 in sub named blah".
